@@ -13,7 +13,7 @@ import (
 	"github.com/stretchr/testify/require"
 	"sigs.k8s.io/kustomize/api/ifc"
 	. "sigs.k8s.io/kustomize/api/internal/target"
-	"sigs.k8s.io/kustomize/api/loader"
+	"sigs.k8s.io/kustomize/api/pkg/loader"
 	"sigs.k8s.io/kustomize/api/provider"
 	"sigs.k8s.io/kustomize/api/resmap"
 	"sigs.k8s.io/kustomize/api/resource"
@@ -79,6 +79,7 @@ func TestLoad(t *testing.T) {
 			k: types.Kustomization{
 				TypeMeta: expectedTypeMeta,
 			},
+			errContains: "kustomization.yaml is empty",
 		},
 		"nonsenseLatin": {
 			errContains: "found a tab character that violates indentation",
