@@ -8,6 +8,7 @@ import (
 
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
+	"sigs.k8s.io/kustomize/api/konfig"
 	testutils_test "sigs.k8s.io/kustomize/kustomize/v5/commands/internal/testutils"
 	"sigs.k8s.io/kustomize/kyaml/filesys"
 )
@@ -38,7 +39,7 @@ func TestAddComponentHappyPath(t *testing.T) {
 }
 
 func TestAddComponentAlreadyThere(t *testing.T) {
-	fSys := filesys.MakeFsInMemory()
+	fSys := filesys.MakeEmptyDirInMemory()
 	err := fSys.WriteFile(componentFileName, []byte(componentFileContent))
 	require.NoError(t, err)
 	testutils_test.WriteTestKustomization(fSys)
@@ -51,19 +52,19 @@ func TestAddComponentAlreadyThere(t *testing.T) {
 	assert.NoError(t, cmd.RunE(cmd, args))
 }
 
+// Test for trying to add the kustomization.yaml file itself for resources.
+// This adding operation is not allowed.
 func TestAddKustomizationFileAsComponent(t *testing.T) {
-	fSys := filesys.MakeFsInMemory()
-	err := fSys.WriteFile(componentFileName, []byte(componentFileContent))
-	require.NoError(t, err)
+	fSys := filesys.MakeEmptyDirInMemory()
 	testutils_test.WriteTestKustomization(fSys)
 
 	cmd := newCmdAddComponent(fSys)
-	args := []string{componentFileName}
+	args := []string{konfig.DefaultKustomizationFileName()}
 	require.NoError(t, cmd.RunE(cmd, args))
 
 	content, err := testutils_test.ReadTestKustomization(fSys)
 	require.NoError(t, err)
-	assert.NotContains(t, string(content), componentFileName)
+	assert.NotContains(t, string(content), konfig.DefaultKustomizationFileName())
 }
 
 func TestAddComponentNoArgs(t *testing.T) {
@@ -73,3 +74,13 @@ func TestAddComponentNoArgs(t *testing.T) {
 	err := cmd.Execute()
 	assert.EqualError(t, err, "must specify a component file")
 }
+
+func TestAddComponentFileNotFound(t *testing.T) {
+	fSys := filesys.MakeEmptyDirInMemory()
+
+	cmd := newCmdAddComponent(fSys)
+	args := []string{componentFileName}
+
+	err := cmd.RunE(cmd, args)
+	assert.EqualError(t, err, componentFileName+" has no match: must build at directory: not a valid directory: '"+componentFileName+"' doesn't exist")
+}
