@@ -33,7 +33,7 @@ func TestByteReader(t *testing.T) {
 		//
 		{
 			name: "wrapped_resource_list",
-			input: `apiVersion: config.kubernetes.io/v1alpha1
+			input: `apiVersion: config.kubernetes.io/v1
 kind: ResourceList
 items:
 -  kind: Deployment
@@ -64,7 +64,7 @@ spec:
 		//
 		{
 			name: "wrapped_resource_list_function_config",
-			input: `apiVersion: config.kubernetes.io/v1alpha1
+			input: `apiVersion: config.kubernetes.io/v1
 kind: ResourceList
 functionConfig:
   foo: bar
@@ -105,7 +105,7 @@ elems:
 		//
 		{
 			name: "wrapped_resource_list_function_config_without_items",
-			input: `apiVersion: config.kubernetes.io/v1alpha1
+			input: `apiVersion: config.kubernetes.io/v1
 kind: ResourceList
 functionConfig:
   foo: bar
@@ -743,7 +743,7 @@ items:
 `},
 			},
 		},
-		"listWithAnchors": {
+		"mergeAnchors": {
 			input: []byte(`
 apiVersion: v1
 kind: DeploymentList
@@ -764,7 +764,59 @@ items:
   metadata:
     name: deployment-b
   spec:
-    *hostAliases
+    <<: *hostAliases
+`),
+			exp: expected{
+				sOut: []string{`
+apiVersion: v1
+kind: DeploymentList
+items:
+- apiVersion: apps/v1
+  kind: Deployment
+  metadata:
+    name: deployment-a
+  spec:
+    template:
+      spec:
+        hostAliases:
+        - hostnames:
+          - a.example.com
+          ip: 8.8.8.8
+- apiVersion: apps/v1
+  kind: Deployment
+  metadata:
+    name: deployment-b
+  spec:
+    template:
+      spec:
+        hostAliases:
+        - hostnames:
+          - a.example.com
+          ip: 8.8.8.8
+`},
+			},
+		},
+		"listWithAnchors": {
+			input: []byte(`
+apiVersion: v1
+kind: DeploymentList
+items:
+- apiVersion: apps/v1
+  kind: Deployment
+  metadata:
+    name: deployment-a
+  spec: &hostAliases
+    template:
+      spec:
+        hostAliases:
+        - hostnames:
+          - a.example.com
+          ip: 8.8.8.8
+- apiVersion: apps/v1
+  kind: Deployment
+  metadata:
+    name: deployment-b
+  spec: *hostAliases
 `),
 			exp: expected{
 				sOut: []string{`
